#!/bin/bash

pkgname="curl"
pkgver="7.62.0"

src="https://curl.haxx.se/download/curl-${pkgver}.tar.gz"

prepare () {
    [ -f "${pkgname}-src.tar.gz" ] || curl -o "${pkgname}-src.tar.gz" "${src}"
    tar -C "${srcdir}" -xvf "${pkgname}-src.tar.gz"
}

build () {
    cd "${srcdir}/curl-${pkgver}"
    mkdir build && cd build

    ../configure \
        --prefix=/usr \
        --mandir=/usr/share/man \
        --disable-dict \
        --disable-gopher \
        --disable-imap \
        --disable-ldap \
        --disable-ldaps \
        --disable-manual \
        --disable-pop3 \
        --disable-rtsp \
        --disable-smb \
        --disable-smtp \
        --disable-telnet \
        --disable-tftp \
        --enable-threaded-resolver \
        --enable-versioned-symbols \
        --with-random=/dev/urandom \
        --with-ssl \
        --with-zlib \
        --without-gssapi \
        --without-libidn2 \
        --without-libmetalink \
        --without-libpsl \
        --without-rtmp

    # TODO: figure out why compiling with SSL is broken.
    #       when SSL is enabled, libtool tries to open
    #       /usr/lib/libcrypto.la (which is not present or
    #       rather not meant to be used at all by this build
    #       process). I wasted 2 hours on debugging this.

    make
}

package () {
    cd "${srcdir}/curl-${pkgver}/build"

    make DESTDIR="${pkgdir}" install
    make DESTDIR="${pkgdir}" install -C scripts
}

. ../common.sh
